==> vkd3d-docs-1.17-2-x86_64.pkg.tar.zst: usr/share/doc/vkd3d/annotated_dup.js <==
var annotated_dup =
[
    [ "vkd3d_application_info", "structvkd3d__application__info.html", "structvkd3d__application__info" ],
    [ "vkd3d_device_create_info", "structvkd3d__device__create__info.html", "structvkd3d__device__create__info" ],
    [ "vkd3d_host_time_domain_info", "structvkd3d__host__time__domain__info.html", "structvkd3d__host__time__domain__info" ],
    [ "vkd3d_image_resource_create_info", "structvkd3d__image__resource__create__info.html", "structvkd3d__image__resource__create__info" ],
    [ "vkd3d_instance_create_info", "structvkd3d__instance__create__info.html", "structvkd3d__instance__create__info" ],
    [ "vkd3d_optional_device_extensions_info", "structvkd3d__optional__device__extensions__info.html", "structvkd3d__optional__device__extensions__info" ],
    [ "vkd3d_optional_instance_extensions_info", "structvkd3d__optional__instance__extensions__info.html", "structvkd3d__optional__instance__extensions__info" ],
    [ "vkd3d_shader_code", "structvkd3d__shader__code.html", "structvkd3d__shader__code" ],
    [ "vkd3d_shader_combined_resource_sampler", "structvkd3d__shader__combined__resource__sampler.html", "structvkd3d__shader__combined__resource__sampler" ],
    [ "vkd3d_shader_combined_resource_sampler_info", "structvkd3d__shader__combined__resource__sampler__info.html", null ],
    [ "vkd3d_shader_compile_info", "structvkd3d__shader__compile__info.html", "structvkd3d__shader__compile__info" ],
    [ "vkd3d_shader_compile_option", "structvkd3d__shader__compile__option.html", "structvkd3d__shader__compile__option" ],
    [ "vkd3d_shader_descriptor_binding", "structvkd3d__shader__descriptor__binding.html", "structvkd3d__shader__descriptor__binding" ],
    [ "vkd3d_shader_descriptor_info", "structvkd3d__shader__descriptor__info.html", "structvkd3d__shader__descriptor__info" ],
    [ "vkd3d_shader_descriptor_offset", "structvkd3d__shader__descriptor__offset.html", null ],
    [ "vkd3d_shader_descriptor_offset_info", "structvkd3d__shader__descriptor__offset__info.html", "structvkd3d__shader__descriptor__offset__info" ],
    [ "vkd3d_shader_descriptor_range", "structvkd3d__shader__descriptor__range.html", null ],
    [ "vkd3d_shader_descriptor_range1", "structvkd3d__shader__descriptor__range1.html", null ],
    [ "vkd3d_shader_dxbc_desc", "structvkd3d__shader__dxbc__desc.html", "structvkd3d__shader__dxbc__desc" ],
    [ "vkd3d_shader_dxbc_section_desc", "structvkd3d__shader__dxbc__section__desc.html", "structvkd3d__shader__dxbc__section__desc" ],
    [ "vkd3d_shader_hlsl_source_info", "structvkd3d__shader__hlsl__source__info.html", "structvkd3d__shader__hlsl__source__info" ],
    [ "vkd3d_shader_interface_info", "structvkd3d__shader__interface__info.html", "structvkd3d__shader__interface__info" ],
    [ "vkd3d_shader_macro", "structvkd3d__shader__macro.html", "structvkd3d__shader__macro" ],
    [ "vkd3d_shader_parameter", "structvkd3d__shader__parameter.html", null ],
    [ "vkd3d_shader_parameter1", "structvkd3d__shader__parameter1.html", "structvkd3d__shader__parameter1" ],
    [ "vkd3d_shader_parameter_buffer", "structvkd3d__shader__parameter__buffer.html", "structvkd3d__shader__parameter__buffer" ],
    [ "vkd3d_shader_parameter_immediate_constant", "structvkd3d__shader__parameter__immediate__constant.html", "structvkd3d__shader__parameter__immediate__constant" ],
    [ "vkd3d_shader_parameter_immediate_constant1", "structvkd3d__shader__parameter__immediate__constant1.html", "structvkd3d__shader__parameter__immediate__constant1" ],
    [ "vkd3d_shader_parameter_info", "structvkd3d__shader__parameter__info.html", "structvkd3d__shader__parameter__info" ],
    [ "vkd3d_shader_parameter_specialization_constant", "structvkd3d__shader__parameter__specialization__constant.html", "structvkd3d__shader__parameter__specialization__constant" ],
    [ "vkd3d_shader_preprocess_info", "structvkd3d__shader__preprocess__info.html", "structvkd3d__shader__preprocess__info" ],
    [ "vkd3d_shader_push_constant_buffer", "structvkd3d__shader__push__constant__buffer.html", "structvkd3d__shader__push__constant__buffer" ],
    [ "vkd3d_shader_resource_binding", "structvkd3d__shader__resource__binding.html", "structvkd3d__shader__resource__binding" ],
    [ "vkd3d_shader_root_constants", "structvkd3d__shader__root__constants.html", null ],
    [ "vkd3d_shader_root_descriptor", "structvkd3d__shader__root__descriptor.html", null ],
    [ "vkd3d_shader_root_descriptor1", "structvkd3d__shader__root__descriptor1.html", null ],
    [ "vkd3d_shader_root_descriptor_table", "structvkd3d__shader__root__descriptor__table.html", null ],
    [ "vkd3d_shader_root_descriptor_table1", "structvkd3d__shader__root__descriptor__table1.html", null ],
    [ "vkd3d_shader_root_parameter", "structvkd3d__shader__root__parameter.html", null ],
    [ "vkd3d_shader_root_parameter1", "structvkd3d__shader__root__parameter1.html", null ],
    [ "vkd3d_shader_root_signature_desc", "structvkd3d__shader__root__signature__desc.html", null ],
    [ "vkd3d_shader_root_signature_desc1", "structvkd3d__shader__root__signature__desc1.html", null ],
    [ "vkd3d_shader_scan_combined_resource_sampler_info", "structvkd3d__shader__scan__combined__resource__sampler__info.html", "structvkd3d__shader__scan__combined__resource__sampler__info" ],
    [ "vkd3d_shader_scan_descriptor_info", "structvkd3d__shader__scan__descriptor__info.html", "structvkd3d__shader__scan__descriptor__info" ],
    [ "vkd3d_shader_scan_hull_shader_tessellation_info", "structvkd3d__shader__scan__hull__shader__tessellation__info.html", "structvkd3d__shader__scan__hull__shader__tessellation__info" ],
    [ "vkd3d_shader_scan_signature_info", "structvkd3d__shader__scan__signature__info.html", "structvkd3d__shader__scan__signature__info" ],
    [ "vkd3d_shader_signature", "structvkd3d__shader__signature.html", "structvkd3d__shader__signature" ],
    [ "vkd3d_shader_signature_element", "structvkd3d__shader__signature__element.html", "structvkd3d__shader__signature__element" ],
    [ "vkd3d_shader_spirv_domain_shader_target_info", "structvkd3d__shader__spirv__domain__shader__target__info.html", null ],
    [ "vkd3d_shader_spirv_target_info", "structvkd3d__shader__spirv__target__info.html", null ],
    [ "vkd3d_shader_static_sampler_desc", "structvkd3d__shader__static__sampler__desc.html", null ],
    [ "vkd3d_shader_transform_feedback_element", "structvkd3d__shader__transform__feedback__element.html", null ],
    [ "vkd3d_shader_transform_feedback_info", "structvkd3d__shader__transform__feedback__info.html", null ],
    [ "vkd3d_shader_uav_counter_binding", "structvkd3d__shader__uav__counter__binding.html", "structvkd3d__shader__uav__counter__binding" ],
    [ "vkd3d_shader_varying_map", "structvkd3d__shader__varying__map.html", "structvkd3d__shader__varying__map" ],
    [ "vkd3d_shader_varying_map_info", "structvkd3d__shader__varying__map__info.html", "structvkd3d__shader__varying__map__info" ],
    [ "vkd3d_shader_versioned_root_signature_desc", "structvkd3d__shader__versioned__root__signature__desc.html", null ]
];

==> vkd3d-docs-1.18-1-x86_64.pkg.tar.zst: usr/share/doc/vkd3d/annotated_dup.js <==
var annotated_dup =
[
    [ "vkd3d_application_info", "structvkd3d__application__info.html", "structvkd3d__application__info" ],
    [ "vkd3d_device_create_info", "structvkd3d__device__create__info.html", "structvkd3d__device__create__info" ],
    [ "vkd3d_host_time_domain_info", "structvkd3d__host__time__domain__info.html", "structvkd3d__host__time__domain__info" ],
    [ "vkd3d_image_resource_create_info", "structvkd3d__image__resource__create__info.html", "structvkd3d__image__resource__create__info" ],
    [ "vkd3d_instance_create_info", "structvkd3d__instance__create__info.html", "structvkd3d__instance__create__info" ],
    [ "vkd3d_optional_device_extensions_info", "structvkd3d__optional__device__extensions__info.html", "structvkd3d__optional__device__extensions__info" ],
    [ "vkd3d_optional_instance_extensions_info", "structvkd3d__optional__instance__extensions__info.html", "structvkd3d__optional__instance__extensions__info" ],
    [ "vkd3d_shader_code", "structvkd3d__shader__code.html", "structvkd3d__shader__code" ],
    [ "vkd3d_shader_combined_resource_sampler", "structvkd3d__shader__combined__resource__sampler.html", "structvkd3d__shader__combined__resource__sampler" ],
    [ "vkd3d_shader_combined_resource_sampler_info", "structvkd3d__shader__combined__resource__sampler__info.html", null ],
    [ "vkd3d_shader_compile_info", "structvkd3d__shader__compile__info.html", "structvkd3d__shader__compile__info" ],
    [ "vkd3d_shader_compile_option", "structvkd3d__shader__compile__option.html", "structvkd3d__shader__compile__option" ],
    [ "vkd3d_shader_d3dbc_source_info", "structvkd3d__shader__d3dbc__source__info.html", "structvkd3d__shader__d3dbc__source__info" ],
    [ "vkd3d_shader_descriptor_binding", "structvkd3d__shader__descriptor__binding.html", "structvkd3d__shader__descriptor__binding" ],
    [ "vkd3d_shader_descriptor_info", "structvkd3d__shader__descriptor__info.html", "structvkd3d__shader__descriptor__info" ],
    [ "vkd3d_shader_descriptor_offset", "structvkd3d__shader__descriptor__offset.html", null ],
    [ "vkd3d_shader_descriptor_offset_info", "structvkd3d__shader__descriptor__offset__info.html", "structvkd3d__shader__descriptor__offset__info" ],
    [ "vkd3d_shader_descriptor_range", "structvkd3d__shader__descriptor__range.html", null ],
    [ "vkd3d_shader_descriptor_range1", "structvkd3d__shader__descriptor__range1.html", null ],
    [ "vkd3d_shader_dxbc_desc", "structvkd3d__shader__dxbc__desc.html", "structvkd3d__shader__dxbc__desc" ],
    [ "vkd3d_shader_dxbc_section_desc", "structvkd3d__shader__dxbc__section__desc.html", "structvkd3d__shader__dxbc__section__desc" ],
    [ "vkd3d_shader_hlsl_source_info", "structvkd3d__shader__hlsl__source__info.html", "structvkd3d__shader__hlsl__source__info" ],
    [ "vkd3d_shader_interface_info", "structvkd3d__shader__interface__info.html", "structvkd3d__shader__interface__info" ],
    [ "vkd3d_shader_macro", "structvkd3d__shader__macro.html", "structvkd3d__shader__macro" ],
    [ "vkd3d_shader_parameter", "structvkd3d__shader__parameter.html", null ],
    [ "vkd3d_shader_parameter1", "structvkd3d__shader__parameter1.html", "structvkd3d__shader__parameter1" ],
    [ "vkd3d_shader_parameter_buffer", "structvkd3d__shader__parameter__buffer.html", "structvkd3d__shader__parameter__buffer" ],
    [ "vkd3d_shader_parameter_immediate_constant", "structvkd3d__shader__parameter__immediate__constant.html", "structvkd3d__shader__parameter__immediate__constant" ],
    [ "vkd3d_shader_parameter_immediate_constant1", "structvkd3d__shader__parameter__immediate__constant1.html", "structvkd3d__shader__parameter__immediate__constant1" ],
    [ "vkd3d_shader_parameter_info", "structvkd3d__shader__parameter__info.html", "structvkd3d__shader__parameter__info" ],
    [ "vkd3d_shader_parameter_specialization_constant", "structvkd3d__shader__parameter__specialization__constant.html", "structvkd3d__shader__parameter__specialization__constant" ],
    [ "vkd3d_shader_preprocess_info", "structvkd3d__shader__preprocess__info.html", "structvkd3d__shader__preprocess__info" ],
    [ "vkd3d_shader_push_constant_buffer", "structvkd3d__shader__push__constant__buffer.html", "structvkd3d__shader__push__constant__buffer" ],
    [ "vkd3d_shader_resource_binding", "structvkd3d__shader__resource__binding.html", "structvkd3d__shader__resource__binding" ],
    [ "vkd3d_shader_root_constants", "structvkd3d__shader__root__constants.html", null ],
    [ "vkd3d_shader_root_descriptor", "structvkd3d__shader__root__descriptor.html", null ],
    [ "vkd3d_shader_root_descriptor1", "structvkd3d__shader__root__descriptor1.html", null ],
    [ "vkd3d_shader_root_descriptor_table", "structvkd3d__shader__root__descriptor__table.html", null ],
    [ "vkd3d_shader_root_descriptor_table1", "structvkd3d__shader__root__descriptor__table1.html", null ],
    [ "vkd3d_shader_root_parameter", "structvkd3d__shader__root__parameter.html", null ],
    [ "vkd3d_shader_root_parameter1", "structvkd3d__shader__root__parameter1.html", null ],
    [ "vkd3d_shader_root_signature_desc", "structvkd3d__shader__root__signature__desc.html", null ],
    [ "vkd3d_shader_root_signature_desc1", "structvkd3d__shader__root__signature__desc1.html", null ],
    [ "vkd3d_shader_scan_combined_resource_sampler_info", "structvkd3d__shader__scan__combined__resource__sampler__info.html", "structvkd3d__shader__scan__combined__resource__sampler__info" ],
    [ "vkd3d_shader_scan_descriptor_info", "structvkd3d__shader__scan__descriptor__info.html", "structvkd3d__shader__scan__descriptor__info" ],
    [ "vkd3d_shader_scan_hull_shader_tessellation_info", "structvkd3d__shader__scan__hull__shader__tessellation__info.html", "structvkd3d__shader__scan__hull__shader__tessellation__info" ],
    [ "vkd3d_shader_scan_signature_info", "structvkd3d__shader__scan__signature__info.html", "structvkd3d__shader__scan__signature__info" ],
    [ "vkd3d_shader_scan_thread_group_size_info", "structvkd3d__shader__scan__thread__group__size__info.html", "structvkd3d__shader__scan__thread__group__size__info" ],
    [ "vkd3d_shader_signature", "structvkd3d__shader__signature.html", "structvkd3d__shader__signature" ],
    [ "vkd3d_shader_signature_element", "structvkd3d__shader__signature__element.html", "structvkd3d__shader__signature__element" ],
    [ "vkd3d_shader_spirv_domain_shader_target_info", "structvkd3d__shader__spirv__domain__shader__target__info.html", null ],
    [ "vkd3d_shader_spirv_target_info", "structvkd3d__shader__spirv__target__info.html", null ],
    [ "vkd3d_shader_static_sampler_desc", "structvkd3d__shader__static__sampler__desc.html", null ],
    [ "vkd3d_shader_transform_feedback_element", "structvkd3d__shader__transform__feedback__element.html", null ],
    [ "vkd3d_shader_transform_feedback_info", "structvkd3d__shader__transform__feedback__info.html", null ],
    [ "vkd3d_shader_uav_counter_binding", "structvkd3d__shader__uav__counter__binding.html", "structvkd3d__shader__uav__counter__binding" ],
    [ "vkd3d_shader_varying_map", "structvkd3d__shader__varying__map.html", "structvkd3d__shader__varying__map" ],
    [ "vkd3d_shader_varying_map_info", "structvkd3d__shader__varying__map__info.html", "structvkd3d__shader__varying__map__info" ],
    [ "vkd3d_shader_versioned_root_signature_desc", "structvkd3d__shader__versioned__root__signature__desc.html", null ]
];
